local acroread=cond(c(os)=="Unix","acroread","AcroRd32")
local variables "pos natio edu brfeed"
capture mkdir tex
capture mkdir tables
capture mkdir figures
use brfeed.dta
/* for each variable a table of frequency and a histogram is generated*/
foreach var of local variables{
	preserve
	local title:variable label `var'
	xcontract `var',nores
	gen perc=string(_perc,"%3.1f")+"\%"
	gen freq=string(_freq)
	decode `var',gen(`var'_label)
	qui sum _freq
	qui gen modal=(_freq==r(max))
	replace `var'_label="\rowcolor[gray]{.9} "+`var'_label if modal==1
	listtex `var'_label freq perc using tables/tab_`var'.tex,rstyle(tabular) headlines("\begin{tabular}{p{5cm}rr}" "\hline \multicolumn{3}{c}{\bf `title'} \\\ " "& Frequency& Percentage \\\ \cline{2-3} ")  footlines("\hline \end{tabular}") replace
	/* a file containing a caption is generated*/
	tempname capt
	file open `capt' using tables/capt_`var'.tex,write replace
	file write `capt' `"\caption{`title'}"' _n
	file close `capt'
	restore
	/* the graphic is temporarily exported to eps, then translated into pdf via ghostscript*/
	qui sum `var'
	local min=r(min)
	local max=r(max)
	hist `var', discrete width(.5)  ylabel(`min'(1)`max',valuelabel angle(hor)) xtitle("") freq ytitle("") graphregion(color(blue*.4)) bcolor(blue) hor
	tempfile graph
	graph export `graph',as(eps) replace
	winexec epstopdf `graph' --outfile=figures/graph_`var'.pdf
	}
/* the main document is generated */
cd tex
tempname main
file open `main' using main_brfeed.tex,write replace
file write `main' `"\documentclass{article}"' _n
file write `main' `"\usepackage{graphicx}"' _n
file write `main' `"\usepackage{color}"' _n
file write `main' `"\usepackage{colortbl}"' _n
file write `main' `"\usepackage[format=hang, labelsep=period,labelfont={bf,small}, textfont=small,width=0.8\textwidth]{caption}"' _n
file write `main' `"\usepackage{hyperref}"' _n
file write `main' `"\newcommand{\dirtab}{../tables}"' _n
file write `main' `"\newcommand{\dirfig}{../figures}"' _n
file write `main' `"\title{Survey on child care behaviours}"' _n
file write `main' `"\begin{document}"' _n
file write `main' `"\maketitle"' _n
file write `main' `"\listoftables"' _n
foreach var of varlist pos natio edu brfeed{
	file write `main' `"\clearpage"' _n
	file write `main' `"\begin{table}\input{\dirtab/capt_`var'.tex}"' _n
	file write `main' `"\centering"' _n
	file write `main' `"\includegraphics[width=.8\textwidth]{\dirfig/graph_`var'.pdf} \\\ "' _n _n
	file write `main' `"\bigskip"' _n
	file write `main' `"\input{\dirtab/tab_`var'.tex}"' _n
	file write `main' `"\end{table}"' _n
	}
file write `main' `"\end{document}"' _n
file close `main'
/* the main document is compiled via pdflatex */
! pdflatex main_brfeed.tex
! pdflatex main_brfeed.tex
/* the main document is opened via acrobat reader*/
winexec `acroread' main_brfeed.pdf
